import { useEffect } from "react";
import styles from "../styles/About.module.css";
// import { AppContext } from "../helpers/helpers";
import AOS from "aos";
import "aos/dist/aos.css";
import { useSelector } from "react-redux";
import { AnimatePresence, motion } from "framer-motion";

const about = () => {
  // const { theme } = useContext(AppContext);
  const theme = useSelector((state) => state.currentTheme.value);

  useEffect(() => {
    AOS.init();
    AOS.refresh();
  }, []);

  useEffect(() => {
    if (localStorage) {
      localStorage.setItem("theme", theme.theme);
    } else {
      console.log("errr");
    }
  }, [theme.theme]);

  return (
    <AnimatePresence>
      <div id={theme.theme} className={styles.container}>
        <div className={styles.main}>
          <div className={styles.textsCon}>
            <h1>About </h1>
            <p>
              Welcome to "Quest of Bengal," an immersive journey into the rich tapestry of Bengal's culture, history,
              and geography through an interactive online board game.
            </p>

              <br/>
              <h3>
                Our Mission:
              </h3>
            <p>
                At "Quest of Bengal," our mission is to provide a captivating and educational experience that celebrates
                the vibrant heritage of Bengal. We aim to inspire curiosity, foster learning, and promote a deeper
                understanding of this culturally diverse region.
            </p>

                <br/>
                <h3>
                  Explore Bengal's Treasures:
                </h3>
            <p>
                Embark on a thrilling adventure as you traverse the virtual landscape of Bengal, encountering
                captivating
                challenges and uncovering hidden gems along the way. From the bustling streets of Kolkata to the serene
                landscapes of the Sundarbans, every corner of Bengal holds a story waiting to be discovered.
            </p>
                <br/>
                <h3>
                  Engage with Bengal's History:
                </h3>
            <p>
                Delve into the annals of Bengal's illustrious history, from ancient civilizations to colonial rule and
                beyond. Learn about the contributions of legendary figures, the struggles of independence movements, and
                the cultural renaissance that shaped Bengal's identity.
            </p>


                <br/>
                <h3>
                  Immerse Yourself in Bengal's Culture:
                </h3>
            <p>
                Experience the vibrancy of Bengal's cultural heritage through captivating visuals, traditional music,
                and
                authentic artwork. Explore the rich traditions of folk art, dance, cuisine, and festivals that have
                stood
                the test of time and continue to thrive in modern-day Bengal.
            </p>

                <br/>
                <h3>
                  Connect with Bengal's People:
                </h3>
            <p>
                Meet the diverse communities that call Bengal home, each with its own unique customs, traditions, and
                dialects. Gain insights into the daily lives of Bengalis, their resilience in the face of challenges,
                and their unwavering spirit of unity and hospitality.
            </p>


                <br/>
                <h3>Join the Adventure:</h3>
            <p>
                Are you ready to embark on the "Quest of Bengal"? Whether you're a history buff, a culture enthusiast,
                or simply curious to learn more about this enchanting region, our interactive board game offers an
                exciting journey that promises to educate, entertain, and inspire.

                Come, join us as we unravel the mysteries and celebrate the wonders of Bengal – one quest at a time. Let
                the adventure begin!
            </p>
            <br></br>
            <p>
              Instructions: To answer any question, Just click on your answer
              and select Next question button, Your answer is recorded when you
              choose an option.{" "}
            </p>
          </div>
        </div>
        <motion.div
          className={styles.slideIn}
          initial={{ scaleY: 0 }}
          animate={{ scaleY: 0 }}
          exit={{ scaleY: 1 }}
          transition={{ duration: 1, ease: [0.22, 1, 0.36, 1] }}
        ></motion.div>
        <motion.div
          className={styles.slideOut}
          initial={{ scaleY: 1 }}
          animate={{ scaleY: 0 }}
          exit={{ scaleY: 0 }}
          transition={{ duration: 1, ease: [0.22, 1, 0.36, 1] }}
        ></motion.div>
      </div>
    </AnimatePresence>
  );
};

export default about;
